<a id="packages.valory.skills.registration_abci.models"></a>

# packages.valory.skills.registration`_`abci.models

This module contains the shared state for the registration abci skill.

<a id="packages.valory.skills.registration_abci.models.SharedState"></a>

## SharedState Objects

```python
class SharedState(BaseSharedState)
```

Keep the current shared state of the skill.

<a id="packages.valory.skills.registration_abci.models.SharedState.__init__"></a>

#### `__`init`__`

```python
def __init__(*args: Any, **kwargs: Any) -> None
```

Initialize the state.

